==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ManagedRuleSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule set.
 * @property ruleGroupOverrides Defines the rule group overrides to apply to the rule set.
 * @property ruleSetType Defines the rule set type to use.
 * @property ruleSetVersion Defines the version of the rule set to use.
 */
public data class ManagedRuleSetArgs(
    public val ruleGroupOverrides: Output<List<ManagedRuleGroupOverrideArgs>>? = null,
    public val ruleSetType: Output<String>,
    public val ruleSetVersion: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs =
        com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs.builder()
            .ruleGroupOverrides(
                ruleGroupOverrides?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ruleSetType(ruleSetType.applyValue({ args0 -> args0 }))
            .ruleSetVersion(ruleSetVersion.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedRuleSetArgs].
 */
@PulumiTagMarker
public class ManagedRuleSetArgsBuilder internal constructor() {
    private var ruleGroupOverrides: Output<List<ManagedRuleGroupOverrideArgs>>? = null

    private var ruleSetType: Output<String>? = null

    private var ruleSetVersion: Output<String>? = null

    /**
     * @param value Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("bvkleihaxfgceyvr")
    public suspend fun ruleGroupOverrides(`value`: Output<List<ManagedRuleGroupOverrideArgs>>) {
        this.ruleGroupOverrides = value
    }

    @JvmName("egkpsnijqvptheab")
    public suspend fun ruleGroupOverrides(vararg values: Output<ManagedRuleGroupOverrideArgs>) {
        this.ruleGroupOverrides = Output.all(values.asList())
    }

    /**
     * @param values Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("qysklnhyhmsgolgb")
    public suspend fun ruleGroupOverrides(values: List<Output<ManagedRuleGroupOverrideArgs>>) {
        this.ruleGroupOverrides = Output.all(values)
    }

    /**
     * @param value Defines the rule set type to use.
     */
    @JvmName("fcqofuipluyuhioj")
    public suspend fun ruleSetType(`value`: Output<String>) {
        this.ruleSetType = value
    }

    /**
     * @param value Defines the version of the rule set to use.
     */
    @JvmName("bbaslqylkepilrwa")
    public suspend fun ruleSetVersion(`value`: Output<String>) {
        this.ruleSetVersion = value
    }

    /**
     * @param value Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("tvvhrqyyuhdjwjij")
    public suspend fun ruleGroupOverrides(`value`: List<ManagedRuleGroupOverrideArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param argument Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("bpsouykpfmumguas")
    public suspend
    fun ruleGroupOverrides(argument: List<suspend ManagedRuleGroupOverrideArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleGroupOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param argument Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("vtscwancdinaeuhd")
    public suspend fun ruleGroupOverrides(
        vararg
        argument: suspend ManagedRuleGroupOverrideArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManagedRuleGroupOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param argument Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("bfeulhwbmaxvllnx")
    public suspend
    fun ruleGroupOverrides(argument: suspend ManagedRuleGroupOverrideArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ManagedRuleGroupOverrideArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param values Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("wxmgwltbcqyarlcn")
    public suspend fun ruleGroupOverrides(vararg values: ManagedRuleGroupOverrideArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param value Defines the rule set type to use.
     */
    @JvmName("ijwjsjmdaytudkxa")
    public suspend fun ruleSetType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleSetType = mapped
    }

    /**
     * @param value Defines the version of the rule set to use.
     */
    @JvmName("dfcffwwlaueyilnl")
    public suspend fun ruleSetVersion(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleSetVersion = mapped
    }

    internal fun build(): ManagedRuleSetArgs = ManagedRuleSetArgs(
        ruleGroupOverrides = ruleGroupOverrides,
        ruleSetType = ruleSetType ?: throw PulumiNullFieldException("ruleSetType"),
        ruleSetVersion = ruleSetVersion ?: throw PulumiNullFieldException("ruleSetVersion"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ManagedRuleSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule set.
 * @property ruleGroupOverrides Defines the rule group overrides to apply to the rule set.
 * @property ruleSetType Defines the rule set type to use.
 * @property ruleSetVersion Defines the version of the rule set to use.
 */
public data class ManagedRuleSetArgs(
    public val ruleGroupOverrides: Output<List<ManagedRuleGroupOverrideArgs>>? = null,
    public val ruleSetType: Output<String>,
    public val ruleSetVersion: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs =
        com.pulumi.azurenative.network.inputs.ManagedRuleSetArgs.builder()
            .ruleGroupOverrides(
                ruleGroupOverrides?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ruleSetType(ruleSetType.applyValue({ args0 -> args0 }))
            .ruleSetVersion(ruleSetVersion.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedRuleSetArgs].
 */
@PulumiTagMarker
public class ManagedRuleSetArgsBuilder internal constructor() {
    private var ruleGroupOverrides: Output<List<ManagedRuleGroupOverrideArgs>>? = null

    private var ruleSetType: Output<String>? = null

    private var ruleSetVersion: Output<String>? = null

    /**
     * @param value Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("nextwvtlhscibilu")
    public suspend fun ruleGroupOverrides(`value`: Output<List<ManagedRuleGroupOverrideArgs>>) {
        this.ruleGroupOverrides = value
    }

    @JvmName("dxxtutpcixkqsoie")
    public suspend fun ruleGroupOverrides(vararg values: Output<ManagedRuleGroupOverrideArgs>) {
        this.ruleGroupOverrides = Output.all(values.asList())
    }

    /**
     * @param values Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("jdnqcccoupxrydhm")
    public suspend fun ruleGroupOverrides(values: List<Output<ManagedRuleGroupOverrideArgs>>) {
        this.ruleGroupOverrides = Output.all(values)
    }

    /**
     * @param value Defines the rule set type to use.
     */
    @JvmName("lrbjdmbhvaudosck")
    public suspend fun ruleSetType(`value`: Output<String>) {
        this.ruleSetType = value
    }

    /**
     * @param value Defines the version of the rule set to use.
     */
    @JvmName("vcndiryqyopjetan")
    public suspend fun ruleSetVersion(`value`: Output<String>) {
        this.ruleSetVersion = value
    }

    /**
     * @param value Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("wfxhdsfrwqlvklgb")
    public suspend fun ruleGroupOverrides(`value`: List<ManagedRuleGroupOverrideArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param argument Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("nkfgqrpdqqmxjwqk")
    public suspend
    fun ruleGroupOverrides(argument: List<suspend ManagedRuleGroupOverrideArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleGroupOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param argument Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("ataydjwnqeydfrux")
    public suspend fun ruleGroupOverrides(
        vararg
        argument: suspend ManagedRuleGroupOverrideArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManagedRuleGroupOverrideArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param argument Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("scrgswsluwuqosty")
    public suspend
    fun ruleGroupOverrides(argument: suspend ManagedRuleGroupOverrideArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ManagedRuleGroupOverrideArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param values Defines the rule group overrides to apply to the rule set.
     */
    @JvmName("tkhcqttrqwhuxjba")
    public suspend fun ruleGroupOverrides(vararg values: ManagedRuleGroupOverrideArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleGroupOverrides = mapped
    }

    /**
     * @param value Defines the rule set type to use.
     */
    @JvmName("anwmhqljbvinqjgg")
    public suspend fun ruleSetType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleSetType = mapped
    }

    /**
     * @param value Defines the version of the rule set to use.
     */
    @JvmName("pywubgtmwakkfvqx")
    public suspend fun ruleSetVersion(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleSetVersion = mapped
    }

    internal fun build(): ManagedRuleSetArgs = ManagedRuleSetArgs(
        ruleGroupOverrides = ruleGroupOverrides,
        ruleSetType = ruleSetType ?: throw PulumiNullFieldException("ruleSetType"),
        ruleSetVersion = ruleSetVersion ?: throw PulumiNullFieldException("ruleSetVersion"),
    )
}
